@@ -15,12 +15,15 @@ use utf8;
 use mro 'c3';
 
 package Dist::Zilla::Role::Subversion;
-$Dist::Zilla::Role::Subversion::VERSION = '1.100910';
+
+BEGIN {
+    $Dist::Zilla::Role::Subversion::VERSION = '1.101580';
+}
 
 # ABSTRACT: does Subversion actions for a distribution
 
 use Moose::Role;
-with 'Dist::Zilla::Role::Plugin';
+with 'Dist::Zilla::Role::Plugin' => { -version => 4.101550 };
 
 use Cwd;
 use English qw(-no_match_vars);
@@ -172,7 +175,7 @@ Dist::Zilla::Role::Subversion - does Subversion actions for a distribution
 
 =head1 VERSION
 
-version 1.100910
+version 1.101580
 
 =head1 DESCRIPTION
 
